@@ -57,7 +57,7 @@ def get_aws_session(account):
 
     # If no keys are on supplied for the account, use sts.assume_role instead
     session = get_local_aws_session()
-    if session.get_credentials().method == 'iam-role':
+    if session.get_credentials().method in ('iam-role', 'assume-role-with-web-identity'):
         sts = session.client('sts')
     else:
         # If we are not running on an EC2 instance, assume the instance role
@@ -150,9 +150,10 @@ def load_plugins():
     return __plugins
 
 
-# Check if the user has opted to use userdata based configuration for DB, and load it if needed
+# Check if any external configuration management is to be used
 if app_config.config_method == 'userdata':
-    get_user_data_configuration()
+    user_data_configuration = get_user_data_configuration()
+    app_config = recursive_update(app_config, user_data_configuration)
 
 elif app_config.config_method == 'vault':
     vault_data = get_vault_configuration(
