@@ -1,5 +1,9 @@
+"""The schema module contains all the database schema objects for Probator. Classes in this module should generally never
+be accessed directly, except in some few cases.  Instead use the correct plugin type classes to access and update the
+records in the database
+"""
 from .base import (BaseModelMixin, LogEvent, Email, ConfigNamespace, ConfigItem, Role, User,
-                   UserRole, AuditLog, SchedulerBatch, SchedulerJob, Template)
+                   UserRole, AuditLog, SchedulerBatch, SchedulerJob, Template, ApiKey)
 from .accounts import AccountType, AccountProperty, Account
 from .issues import IssueTypeModel, IssuePropertyModel, IssueModel
 from .resource import Tag, ResourceType, ResourceProperty, Resource, ResourceMapping
@@ -7,5 +11,5 @@ from .resource import Tag, ResourceType, ResourceProperty, Resource, ResourceMap
 __all__ = (
     'ResourceType', 'ResourceProperty', 'Resource', 'ResourceMapping', 'BaseModelMixin', 'Account', 'Tag', 'LogEvent',
     'Email', 'ConfigNamespace', 'ConfigItem', 'Role', 'User', 'UserRole', 'AuditLog', 'SchedulerBatch', 'SchedulerJob',
-    'IssueTypeModel', 'IssuePropertyModel', 'IssueModel', 'Template', 'AccountType', 'AccountProperty', 'Account'
+    'IssueTypeModel', 'IssuePropertyModel', 'IssueModel', 'Template', 'AccountType', 'AccountProperty', 'Account', 'ApiKey'
 )
