@@ -20,7 +20,7 @@ from probator.utils import (
 
 __all__ = (
     'BaseModelMixin', 'LogEvent', 'Email', 'ConfigNamespace', 'ConfigItem', 'Role', 'User',
-    'UserRole', 'AuditLog', 'SchedulerBatch', 'SchedulerJob', 'Template'
+    'UserRole', 'AuditLog', 'SchedulerBatch', 'SchedulerJob', 'Template', 'ApiKey'
 )
 
 log = getLogger(__name__)
@@ -434,6 +434,14 @@ class AuditLog(Model, BaseModelMixin):
 
 
 class SchedulerBatch(Model, BaseModelMixin):
+    """SchedulerBatch model
+
+    Attributes:
+        batch_id (str): Unique ID for the job batch
+        status (str): Status of the batch
+        started (datetime): Time the batch was opened
+        completed (datetime): Time when all jobs in the batch were completed
+    """
     __tablename__ = 'scheduler_batches'
 
     batch_id = Column(String(36), primary_key=True)
@@ -467,6 +475,14 @@ class SchedulerBatch(Model, BaseModelMixin):
 
 
 class SchedulerJob(Model, BaseModelMixin):
+    """SchedulerJob model
+
+    Attributes:
+        job_id (str): Scheduler job ID (uuid)
+        batch_id (str): Batch ID the jobs was created in
+        status (int): Numeric status of the job run
+        data (any): Any data related to the job execution
+    """
     __tablename__ = 'scheduler_jobs'
 
     job_id = Column(String(36), primary_key=True)
@@ -496,8 +512,95 @@ class SchedulerJob(Model, BaseModelMixin):
 
 
 class Template(Model, BaseModelMixin):
+    """Template model
+
+    Attributes:
+        template_name (str): Template name
+        template (str): Template contents
+        is_modified (int): 1 if template has been modified by the user, 0 otherwise
+    """
     __tablename__ = 'templates'
 
     template_name = Column(String(50), primary_key=True)
     template = Column(Text, nullable=False)
     is_modified = Column(TinyInt, default=0, nullable=False)
+
+
+class ApiKey(Model, BaseModelMixin):
+    """Api Key model
+
+    Attributes:
+        api_key_id (string): Unique API Key id
+        secret_key (string): Secret Key
+    """
+    __tablename__ = 'api_keys'
+
+    api_key_id = Column(String(36), primary_key=True)
+    secret_key = Column(String(100), nullable=False)
+    created = Column(DateTime(), nullable=False, server_default=func.utcnow())
+    last_used = Column(DateTime())
+    description = Column(String(200), nullable=False)
+    roles = relationship(
+        'Role',
+        uselist=True,
+        lazy='joined',
+        secondary='api_key_roles',
+        order_by=Role.role_id)
+
+    def add_role(self, roles):
+        """Add roles to an Api Key
+
+        Args:
+            roles ([Role]): List of roles to add
+
+        Returns:
+            ApiKey
+        """
+        for role in roles:
+            api_key_role = ApiKeyRole()
+            api_key_role.api_key_id = self.api_key_id
+            api_key_role.role_id = role.role_id
+            db.session.add(api_key_role)
+
+        db.session.commit()
+
+        return self
+
+    @classmethod
+    def from_json(cls, data):
+        """Return object based on JSON / dict input
+
+        Args:
+            data (dict): Dictionary containing a serialized User object
+
+        Returns:
+            :obj:`ApiKey`: Api Key object representing the data
+        """
+        api_key = ApiKey()
+
+        api_key.api_key_id = data['apiKeyId']
+        api_key.secret_key = data['secretKey']
+        api_key.created = data['created']
+        api_key.last_used = data['lastUsed']
+        api_key.description = data['description']
+        api_key.roles = data['roles']
+
+        return api_key
+
+
+class ApiKeyRole(Model, BaseModelMixin):
+    """API Key to role mapping object
+
+    Warnings:
+        This object should never be accessed directly, it should only be updated by SQLAlchemy
+
+    Attributes:
+        api_role_id (int): Internal unique ID
+        api_key_id (int): ID of the user
+        role_id (int): ID of the role
+    """
+    __tablename__ = 'api_key_roles'
+
+    api_role_id = Column(Integer, primary_key=True, autoincrement=True)
+    api_key_id = Column(String(36), ForeignKey(ApiKey.api_key_id, name='fk_api_key_role_user', ondelete='CASCADE'))
+    role_id = Column(Integer, ForeignKey(Role.role_id, name='fk_api_key_role_role', ondelete='CASCADE'))
