@@ -255,16 +255,20 @@ def isoformat(date):
     return date.isoformat() if date else None
 
 
-def generate_password(length=32):
+def generate_password(length=32, characters=None):
     """Generate a cryptographically secure random string to use for passwords
 
     Args:
         length (int): Length of password, defaults to 32 characters
+        characters (string): String of characters to use for passwords. Default: a-zA-Z0-9!@#$+.,
 
     Returns:
         Randomly generated string
     """
-    return ''.join(random.SystemRandom().choice(string.ascii_letters + '!@#$+.,') for _ in range(length))
+    if not characters:
+        characters = string.ascii_letters + string.digits + '!@#$+.,'
+
+    return ''.join(random.SystemRandom().choice(characters) for _ in range(length))
 
 
 def generate_csrf_token():
@@ -476,10 +480,10 @@ def parse_date(date_string, ignoretz=True):
 
 
 def get_user_data_configuration():
-    """Retrieve and update the application configuration with information from the user-data
+    """Returns the application configuration with information from the user-data
 
     Returns:
-        `None`
+        `str`
     """
     from probator import get_local_aws_session, app_config
 
@@ -502,9 +506,7 @@ def get_user_data_configuration():
 
     if res.status_code == 200:
         data = kms.decrypt(CiphertextBlob=b64decode(res.content))
-        kms_config = json.loads(zlib.decompress(data['Plaintext'], wbits=zlib.MAX_WBITS | 32).decode('utf-8'))
-
-        app_config.database_uri = kms_config['db_uri']
+        return json.loads(zlib.decompress(data['Plaintext'], wbits=zlib.MAX_WBITS | 32).decode('utf-8'))
     else:
         raise RuntimeError(f'Failed loading user-data, cannot continue: {res.status_code}: {res.content}')
 
@@ -523,16 +525,6 @@ def get_vault_configuration(*, kms_region, role_id, secret_id, address, path):
         `munch.Munch`
     """
     from probator import get_local_aws_session
-    env_vars = {
-        'PROBATOR_KMS_REGION': 'kms_region',
-        'PROBATOR_VAULT_ROLE_ID': 'role_id',
-        'PROBATOR_VAULT_SECRET_ID': 'secret_id',
-        'PROBATOR_VAULT_ADDRESS': 'address',
-        'PROBATOR_VAULT_PATH': 'path'
-    }
-    for env_var, mapped_var in env_vars.items():
-        if env_var in os.environ:
-            pass
 
     try:
         session = get_local_aws_session()
@@ -588,8 +580,9 @@ def read_config():
     a `Munch` (dict-like object) containing the configuration
 
     Configuration file paths searched, in order:
-        * ~/.probator/config.json'
+        * ~/.probator/config.json
         * ./config.json
+        * /etc/probator
         * /usr/local/etc/probator/config.json
 
     Returns:
